@@ -1,5 +1,3 @@
-use std::time::Instant;
-
 use bevy::{
     core::FixedTimestep,
     prelude::*,
@@ -9,7 +7,9 @@ use bevy::{
 use bevy_simple_tilemap::prelude::*;
 
 fn main() {
-    App::build()
+    App::new()
+        // Disable MSAA, as it produces weird rendering artifacts
+        .insert_resource(Msaa { samples: 1 })
         .add_plugins(DefaultPlugins)
         .add_plugin(SimpleTileMapPlugin)
         .add_system(update_tiles_system.system().with_run_criteria(FixedTimestep::step(0.5)))
@@ -21,14 +21,14 @@ fn main() {
 fn input_system(
     active_cameras: Res<ActiveCameras>,
     mut camera_transform_query: Query<(&mut Transform,), With<Camera>>,
-    mut tilemap_visible_query: Query<&mut Visible, With<TileMap>>,
+    mut tilemap_visible_query: Query<&mut Visibility, With<TileMap>>,
     keyboard_input: Res<Input<KeyCode>>,
     time: Res<Time>,
 ) {
     const MOVE_SPEED: f32 = 1000.0;
     const ZOOM_SPEED: f32 = 10.0;
 
-    if let Some(active_camera_entity) = active_cameras.get("Camera2d").and_then(|ac| ac.entity) {
+    if let Some(active_camera_entity) = active_cameras.get("camera_2d").and_then(|ac| ac.entity) {
         if let Ok((mut tf,)) = camera_transform_query.get_mut(active_camera_entity) {
             if keyboard_input.pressed(KeyCode::X) {
                 tf.scale -= Vec3::splat(ZOOM_SPEED) * time.delta_seconds();
@@ -59,8 +59,6 @@ fn input_system(
 
 /// Draw line of foreground (layer 1) tiles, moving it up by one each time
 fn update_tiles_system(mut query: Query<&mut TileMap>, mut count: Local<i32>) {
-    let upd_tiles = Instant::now();
-
     let line_y = *count % 10;
 
     for mut tilemap in query.iter_mut() {
@@ -84,8 +82,6 @@ fn update_tiles_system(mut query: Query<&mut TileMap>, mut count: Local<i32>) {
         tilemap.set_tiles(tiles);
     }
 
-    dbg!(upd_tiles.elapsed());
-
     *count += 1;
 }
 
